<?php
/**
 * @file
 * @author e-Commerce Dev Team
 * Create file products. Enable the download only after the
 * payment and set date to expire.
 */

/**
 * Add a new field on each Attachment. This will mark the file
 * as a product
 *
 * @param &$form
 *   Array, the form array
 * @param $files
 *   Array, the form fields that deals with file attachments
 */
function _ec_file_form_change(&$form, $files, $form_id) {
  foreach (element_children($files) as $id) {
    $result = db_result(db_query('SELECT fid FROM {ec_file} WHERE nid = %d and fid = %d', $form['nid']['#value'], $id));
    $files[$id]['product'] = array(
      '#default_value'  => $result,
      '#type'           => 'checkbox'
      );
  }

  // Overwrite the theme function upload_form_current
  $files['#theme'] = 'ec_file_upload_form';

  if ($form_id == 'upload_js') {
    $form['files'] = $files;
  }
  else {
    $form['attachments']['wrapper']['files'] = $files;
  }
}

/**
 * Sends a logged in user to their purchased file listing.
 */
function ec_file_redirect_to_display_files() {
  global $user;
  drupal_goto("user/$user->uid/store/myfiles");
}

/**
 * Display a user's purchased files as a table list.
 *
 */
//TODO: do we need $user?
function ec_file_display_purchased_files_as_table($user) {
  $files = ec_file_purchased_files($user);
  return theme('ec_file_myfiles', $files);
}


/**
 * Display a user's purchased files in a block.
 *
 */
//TODO: do we need $user?
function ec_file_display_purchased_files_as_block($user) {
  $files = ec_file_purchased_files($user);
  return theme('ec_file_myfiles_link_list', $files);
}

/**
 * Returns all files purchased by a user.
 *
 * TODO: the comment below is old. Still relevant?
 * Note:
 * Expiration date is found via the sitewide file expiration date OR the
 * special case where a store admin has extended the expiration date for a given
 * transaction. The 'special case' always take precedence, so you can disable
 * downloads before the sitewide expiration date is reached.
 *
 * @param $user
 *   A user object
 * @return
 *   Array of purchased files
 */
function ec_file_purchased_files($user) {
  //TODO: add in expiration handling by setting $expired <= 1; in the for loop below
  /*
   * if $expired = 0, then the files aren't expired
   * if $expired = 1, then the files are expired
   */
  for ($expired = 0; $expired <= 0; $expired++) {
    /* if (empty($expired)) {
      $status = ECRECURRING_STATUS_ACTIVE;
    }
    else {
      $status = ECRECURRING_STATUS_EXPIRED;
    }*/

    $files[$expired] = array();
    $header = array(
      array('data' => t('Filename'), 'field' => 't.txnid', 'sort' => 'desc'),
      array('data' => t('Size'), 'field' => 'epf.size'),
      //array('data' => ($expired) ? t('Expired') : t('Expires'), 'field' => 'ere.expiry'),
      array('data' => t('Transaction'), 'field' => 'etp.txnid')
    );

    //Return all file downloads for the user
    $result = db_query('SELECT etp.title, f.filesize, f.filepath, t.workflow, etp.txnid
      FROM {ec_transaction} t
      INNER JOIN {ec_customer} ecc ON t.ecid = ecc.ecid
      INNER JOIN {ec_transaction_product} etp ON etp.txnid = t.txnid
      INNER JOIN {ec_file} epf ON epf.nid = etp.nid
      INNER JOIN {files} f ON f.fid = epf.fid
      WHERE ecc.uid = %d'.
      tablesort_sql($header), $user->uid);

    while ($data = db_fetch_object($result)) {
      if (!empty($cache[$data->filepath])) {
        continue;
      }
      $cache[$data->filepath] = TRUE;
      $files[$expired][] = $data;
    }
  }
  return $files;
}